[SCM] exiv2 packaging branch, master, updated. debian/0.25-3.1-3734-gdcbc29a

Maximiliano Curia maxy at moszumanska.debian.org
Thu Jul 13 17:41:34 UTC 2017


Gitweb-URL: http://git.debian.org/?p=pkg-kde/kde-extras/exiv2.git;a=commitdiff;h=34a3783

The following commit has been merged in the master branch:
commit 34a3783e9a83b2ef1209baca07c1677eb55621f8
Author: HumanDynamo <caulier.gilles at gmail.com>
Date:   Tue Apr 27 10:18:50 2010 +0000

    and another one : TeleconverterModel is also shared between Minolta and Sony
---
 src/minoltamn.cpp         |  6 ++++++
 src/minoltasonyvalues.cpp | 18 +++++++++++++++++-
 src/minoltasonyvalues.hpp |  3 +++
 src/sonymn.cpp            | 11 +----------
 4 files changed, 27 insertions(+), 11 deletions(-)

diff --git a/src/minoltamn.cpp b/src/minoltamn.cpp
index 7775adc..143bfec 100644
--- a/src/minoltamn.cpp
+++ b/src/minoltamn.cpp
@@ -135,6 +135,12 @@ namespace Exiv2 {
 
         // TODO: Tag 0x0103 : quality or image size (see ExifTool doc).
 
+        TagInfo(0x0104, "FlashExposureComp", N_("Flash Exposure Compensation"),
+                N_("Flash exposure compensation in EV"),
+                minoltaIfdId, makerTags, signedRational, printValue),
+        TagInfo(0x0105, "Teleconverter", N_("Teleconverter Model"),
+                N_("Teleconverter Model"),
+                sony1IfdId, makerTags, unsignedLong, printMinoltaSonyTeleconverterModel),
         TagInfo(0x0107, "ImageStabilization", N_("Image Stabilization"),
                 N_("Image stabilization"),
                 minoltaIfdId, makerTags, unsignedLong, EXV_PRINT_TAG(minoltaImageStabilization)),
diff --git a/src/minoltasonyvalues.hpp b/src/minoltasonyvalues.hpp
index 3b97bd9..64b6d0d 100644
--- a/src/minoltasonyvalues.hpp
+++ b/src/minoltasonyvalues.hpp
@@ -76,6 +76,9 @@ namespace Exiv2 {
     //! Print Minolta/Sony Image Quality values to readable labels.
     std::ostream& printMinoltaSonyImageQuality(std::ostream&, const Value&, const ExifData*);
 
+    //! Print Minolta/Sony Teleconverter Model values to readable labels.
+    std::ostream& printMinoltaSonyTeleconverterModel(std::ostream&, const Value&, const ExifData*);
+
     // TODO: Added shared methods here.
 
 }                                       // namespace Exiv2
diff --git a/src/sonymn.cpp b/src/sonymn.cpp
index 38c44c0..b70b7d1 100644
--- a/src/sonymn.cpp
+++ b/src/sonymn.cpp
@@ -49,15 +49,6 @@ namespace Exiv2 {
 
     // -- Standard Sony Makernotes tags ---------------------------------------------------------------
 
-    //! Lookup table to translate Sony teleconverter model values to readable labels
-    extern const TagDetails sonyTeleconverterModel[] = {
-        { 0x00, N_("None")                     },
-        { 0x48, N_("Minolta AF 2x APO (D)")    },
-        { 0x50, N_("Minolta AF 2x APO II")     },
-        { 0x88, N_("Minolta AF 1.4x APO (D)")  },
-        { 0x90, N_("Minolta AF 1.4x APO II")   }
-    };
-
     //! Lookup table to translate Sony Std camera settings white balance values to readable labels
     extern const TagDetails sonyWhiteBalanceStd[] = {
         { 0x00,  N_("Auto")                           },
@@ -217,7 +208,7 @@ namespace Exiv2 {
                 sony1IfdId, makerTags, signedRational, printValue),
         TagInfo(0x0105, "Teleconverter", N_("Teleconverter Model"),
                 N_("Teleconverter Model"),
-                sony1IfdId, makerTags, unsignedLong, EXV_PRINT_TAG(sonyTeleconverterModel)),
+                sony1IfdId, makerTags, unsignedLong, printMinoltaSonyTeleconverterModel),
         TagInfo(0x0112, "WhiteBalanceFineTune", N_("White Balance Fine Tune"),
                 N_("White Balance Fine Tune Value"),
                 sony1IfdId, makerTags, unsignedLong, printValue),

diff --git a/src/minoltasonyvalues.cpp b/src/minoltasonyvalues.cpp
index 26cd019..b64726c 100644
--- a/src/minoltasonyvalues.cpp
+++ b/src/minoltasonyvalues.cpp
@@ -499,7 +499,7 @@ namespace Exiv2 {
 
     // ----------------------------------------------------------------------------------------------------
 
     //! Lookup table to translate Sony image quality values to readable labels
     extern const TagDetails minoltaSonyImageQuality[] = {
         { 0, N_("Raw")                   },
         { 1, N_("Super Fine")            },
@@ -516,4 +516,20 @@ namespace Exiv2 {
     {
         return EXV_PRINT_TAG(minoltaSonyImageQuality)(os, value, metadata);
     }
+
+    // ----------------------------------------------------------------------------------------------------
+
+    //! Lookup table to translate Sony/Minolta teleconverter model values to readable labels
+    extern const TagDetails minoltaSonyTeleconverterModel[] = {
+        { 0x00, N_("None")                     },
+        { 0x48, N_("Minolta AF 2x APO (D)")    },
+        { 0x50, N_("Minolta AF 2x APO II")     },
+        { 0x88, N_("Minolta AF 1.4x APO (D)")  },
+        { 0x90, N_("Minolta AF 1.4x APO II")   }
+    };
+
+    std::ostream& printMinoltaSonyTeleconverterModel(std::ostream& os, const Value& value, const ExifData* metadata)
+    {
+        return EXV_PRINT_TAG(minoltaSonyTeleconverterModel)(os, value, metadata);
+    }
 }                                       // namespace Exiv2
@@ -499,7 +499,7 @@ namespace Exiv2 {
     // ----------------------------------------------------------------------------------------------------
 
-    //! Lookup table to translate Sony image quality values to readable labels
+    //! Lookup table to translate Sony/Minolta image quality values to readable labels
     extern const TagDetails minoltaSonyImageQuality[] = {
         { 0, N_("Raw")                   },
-- 
exiv2 packaging



More information about the pkg-kde-commits mailing list